[PATCH 0/2] Skip a connectivity check during fetch --filter
- From
- Jonathan Tan <jonathantanmy@google.com>
- Date
- Jan 12, 2020, 04:15 UTC
- Message-ID
- <cover.1578802317.git.jonathantanmy@google.com>
The same optimization in dfa33a298d ("clone: do faster object check for partial clones", 2019-04-21) can be applied to fetch as well, so this patch set does so. Patch 1 makes the check more robust, and patch 2 applies it to one of two connectivity checks performed during the fetch.
As mentioned in patch 2, when fetching from a local repo, I got a speedup of 6.63s to 3.39s.
Jonathan Tan (2): connected: verify promisor-ness of partial clone fetch: forgo full connectivity check if --filter
builtin/clone.c | 5 +++-- builtin/fetch.c | 11 ++++++++++- connected.c | 19 ++++++++++++++----- connected.h | 11 ++++++----- 4 files changed, 33 insertions(+), 13 deletions(-)
-- 2.25.0.rc1.283.g88dfdc4193-goog